 .. _documentation:

=============
Documentation
=============

In this section, we cover the core concepts in *GraKeL* and show how to use it.

  .. toctree::
    :maxdepth: 1

    documentation/installation
    documentation/introduction
    documentation/core_concepts
    documentation/creating_kernels
    documentation/contributing